
# Telegram Bot Manager

The bot for manager easily telegram groups. Just
using config.ini


## 🚀 About me
André Conjo Software Engineer
Email: andrehconjo@gmail.com


## Autores

- [@andreconjo](https://www.github.com/andreconjo)

